@@ -10,26 +10,28 @@ class EventSimpleGUI:
         self._events = []
 
     @property
-    def get_events(self):
+    def get_events(self) -> list:
         """ Use this property to get all events, from @event or add_event """
         return self._events
 
     def add_event(self, event):
-        """ You can use this method, but it's recomended to use @EventSimpleGUI.event"""
+        """ You can use this method, but it's recomended to use @EventSimpleGUI.event """
         self._events.append(event)
 
-    def run_window(self, Window: sg.Window, *args, debug=False, close_event=False, return_values=True, task=None):
+    def run_window(
+            self, Window: sg.Window, *args, window_log=False, close_event=False, return_values=True, task=None
+    ) -> dict or None:
         """ Use this method to run PySimpleGUI Windows
         :param Window:         can be any PySimpleGUI Window
         :type Window:          PySimpleGUI.Window
         :arg args:             can be any function that recives (event: str , values: dict, window: PySimpleGUI.Window)
         :type args:            function
-        :param debug:          if True prints events and values on the console
-        :type debug:           bool
+        :param window_log:     if True prints events and values on the console
+        :type window_log:      bool
         :param return_values:  if True return values of window.read()
         :type return_values:   bool
         :param task:           can be any calable function
-        :param close_event:
+        :param close_event:    a diferent key to close the window
         """
         while True:
 
@@ -50,25 +52,25 @@ class EventSimpleGUI:
             for func in self._events:
                 func(event, values, Window)
 
+
             # Run args events or functions
             for arg in args:
                 arg(event, values, Window)
 
             # Activate debug
-            if debug:
-                print('Event -> ', event)
-                print('Values -> ', values)
+            if window_log:
+                print(f'{"Event ->":10}', event)
+                print(f'{"Values ->":10}', values)
 
         # Return values of window.read()
         if return_values:
             return values
         Window.close()
 
-
-    def event(self, key: str):
+    def event(self, key: str or list[str]):
         """ Use this decorator to create events.
-        ::param key:     element key
-        ::type key:      str
+        ::param key:     element key or keys
+        ::type key:      str or list[str]
 
         Exemple of a simple event:
 
@@ -81,9 +83,15 @@ class EventSimpleGUI:
         """
         def decorador(func_event):
             def empacotador(event: str, values: dict, window: sg.Window):
-                if event == key:
-                    result = func_event(event, values, window)
-                    return result
+                if type(key) == list:
+                    if event in key:
+                        values[func_event.__name__] = func_event(event, values, window)
+                        return values[func_event.__name__]
+
+                elif type(key) == str:
+                    if event == key:
+                        values[func_event.__name__] = func_event( event, values, window )
+                        return values[func_event.__name__]
             self.add_event(empacotador)
             return empacotador
         return decorador
